---
title: <span class="badge object-type-scalar"></span> Pound
---
# <span class="badge object-type-scalar"></span> Pound

Mass: pound (lb)

## Definition

```python
# Mass: pound (lb)
Pound: typing.Literal["masslb"] = "masslb"
```
